@REM
@REM Copyright (c) 2021-2023, AlterBasics Technologies Pvt Ltd.
@REM
@REM All Rights Reserved.
@REM You may not use this file except in compliance with the License.
@REM
@REM You may obtain a copy of the License at
@REM
@REM https://colrows.com/license.txt
@REM

@echo off




echo ==========================================================================
echo =========================== COLROWS CLI TOOL =============================
echo ==========================================================================
echo Choose Option : press numeric key for specific operation
echo 1. Import .cer/.p12 to keystore
echo 2. Download Driver Maven dependencies

set /P option=Enter your option:


IF %option% == 1 goto importCert
if %option% == 2 goto downloadArtifact

echo Not found.
goto exit


:importCert
   set /p path= Enter your crt/p12 path
   set /p password= Enter password is applicable [leave blank for .crt file import]
   set /p keystoreLoc= Enter keystore location [default location: /colrows/]
   set /p keyStorePassword= Enter keystore password [leave blank for default password]

   echo "importing file: %path% to keystore: %keystoreLoc%"

   FOR %%i IN ("%path%") DO (
	set fileextension=%%~xi
	)

	echo file extension %fileextension%

   IF %fileextension% NEQ .crt (
	IF %fileextension% NEQ .p12 (
		ECHO only CRT/P12 file supported
		goto exit
	)
	)



    set cmd= import
    IF %fileextension% EQU .crt (
    set cmd=%cmd% -certificate %path%
    )

    IF %fileextension% EQU .p12 (
        set cmd=%cmd% -pkcs12 %path%
    )

    IF [%password%] NEQ [] (
        set cmd=%cmd% -pkcs12Pass %password%
    )

    IF [%keystoreLoc%] NEQ [] (
        set cmd=%cmd% -keystore %keystoreLoc%
    )else (
		echo setting default keystore location
		set cmd=%cmd% -keystore /colrows.jks
	)

    IF [%keyStorePassword%] NEQ [] (
            set cmd=%cmd% -keystorePassword %keyStorePassword%
    )else (
		echo setting default keystore password
		set cmd=%cmd% -keystorePassword colrows
	)

	echo executing command %cmd%
	cd..

	"%JAVA_HOME%\bin\java" -cp "./lib/*" abs.colrows.cli.CliApplication %cmd%
	goto exit


:downloadArtifact
	echo  --------------- Download Artifact -----------------
	set /p product= Enter Product name e.g. mysql :
	set /p sourceURL= Enter maven source URL : (default: https://repo.maven.apache.org/maven2) :
	set /p sourceUsername= Enter Maven source username (leave blank for default) :
	set /p sourcePassword= Enter Maven source password (leave blank for default) :
	set /p targetURL= Enter target location to store : (default: colrows/driver) :
	set /p destUsername= Enter Maven destination username (leave blank for default) :
	set /p destPassword= Enter Maven destination password (leave blank for default) :
	set /p artifact= Enter Artifact cordinates [e.g. org.apache.commons:commons-lang3:3.3.2] :

	set cmd= download
	echo validating product
	IF [%product%] NEQ [] ( set cmd=%cmd% -product %product%) ELSE ( echo ERROR: product is requiredgoto exit )
	echo validating source URL
	IF [%sourceURL%] NEQ [] ( set cmd=%cmd% -sourceUrl %sourceURL%) ELSE ( set cmd=%cmd% -sourceUrl https://repo.maven.apache.org/maven2 )

	IF [%sourceUsername%] NEQ [] (
		set cmd=%cmd% -sourceUsername %sourceUsername%
	)

	IF [%sourcePassword%] NEQ [] (
		set cmd=%cmd% -sourcePassword %sourcePassword%
	)

	IF [%targetURL%] NEQ [] (
		set cmd=%cmd% -targetUrl %targetURL%
	) else (

		set targetURL=./drivers
		echo setting default driver path %targetURL%
		set cmd=%cmd% -targetUrl ./drivers
	)
	echo target URL : %targetURL%
	echo cmd : %cmd%

	IF [%destUsername%] NEQ [] (
		set cmd=%cmd% -username %destUsername%
	)

	IF [%destPassword%] NEQ [] (
		set cmd=%cmd% -password %destPassword%
	)

	IF [%artifact%] NEQ [] (
		set cmd=%cmd% -artifactCoordinates %artifact%
	) else (
		echo ERROR: Artifact is required
		goto exit
	)

	echo executing command : %cmd%
    cd..
    "%JAVA_HOME%\bin\java" -cp "./lib/*" abs.colrows.cli.CliApplication %cmd%

    for /f "tokens=3 delims=:" %%A in ("%artifact%") Do set version=%%A
    set RootDir=%targetURL%/%product%/%version%

    echo "Moving jars to base location %RootDir%"
    FOR /R %RootDir% %%i IN (*.jar) DO MOVE "%%i" %RootDir%

    echo "deleting additional files"
    for /d %%a in ("%RootDir%\*") do rd "%%a" /q /s
    goto exit

: exit
pause