#!/bin/sh
#
# Copyright (c) 2021-2023, AlterBasics Technologies Pvt Ltd.
#
# All Rights Reserved.
# You may not use this file except in compliance with the License.
#
# You may obtain a copy of the License at
#
# https://colrows.com/license.txt
#

pushd ../


importCert () {
   echo "Enter your crt/p12 path"
   read path
   echo "Enter password is applicable [leave blank for .crt file import]"
   read password
   echo "Enter keystore location [default location: /colrows/]"
   read keystoreLoc
   echo "Enter keystore password [leave blank for default password]"
   read keyStorePassword
   echo "importing file: $path to keystore: $keystoreLoc"
   extension="${path##*.}"
   echo "extension found:$extension"
   if ([ "$extension" != "crt" ] && [ "$extension" != "p12" ])
   then
           echo "only CRT/P12 file supported"
           exit 1;
   fi

        echo "current directory"
        pwd
   app=`ls ../lib/colrows-cli*.jar`
   echo "Invoking application : $app"
   java -cp "$app:../lib/*" abs.colrows.cli.CliApplication import
}
downloadArtifact () {
  echo " --------------- Download Artifact -----------------"
  echo "Enter Product name : e.g. mysql"
  read product
  echo "Enter maven source URL : (default: https://repo.maven.apache.org/maven2)"
  read sourceURL
  echo "Enter Maven source username (leave blank for default)"
  read sourceUsername
  echo "Enter Maven source password (leave blank for default)"
  read sourcePassword

  echo "Enter target location to store : (default: colrows/driver)"
  read targetURL
  echo "Enter Maven destination username (leave blank for default)"
  read destUsername
  echo "Enter Maven destination password (leave blank for default)"
  read destPassword


  echo "Enter Artifact cordinates e.g. org.apache.commons:commons-lang3:3.3.2|com.google.inject:guice:jar:no_aop:3.0"
  read artifact

  cmd="download"
  if [ "$product" != "" ];
  then
          cmd="$cmd -product $product"
  else
          echo "ERROR: product is required"
          exit 1;
  fi

  if [ "$sourceURL" != "" ];
  then
          cmd="$cmd -sourceUrl $sourceURL"
  else
          cmd="$cmd -sourceUrl https://repo.maven.apache.org/maven2"
  fi

  if [ "$sourceUsername" != "" ];
  then
          cmd="$cmd -sourceUsername $sourceUsername"
  fi

  if [ "$sourcePassword" != "" ];
  then
          cmd="$cmd -sourcePassword $sourcePassword"
  fi

  if [ "$targetURL" != "" ];
  then
          cmd="$cmd -targetUrl $targetURL"
  else
	  targetURL="../drivers"
          cmd="$cmd -targetUrl ../drivers"
  fi

  if [ "$destUsername" != "" ];
  then
          cmd="$cmd -username $destUsername"
  fi

  if [ "$destPassword" != "" ];
  then
          cmd="$cmd -password $destPassword"
  fi

  if [ "$artifact" != "" ];
  then
          cmd="$cmd -artifactCoordinates $artifact"
  else
          echo "ERROR: Artifact is required"
          exit 1;
  fi

  echo "executing command : $cmd"
  app=`ls ../lib/colrows-cli*.jar`
  echo "Invoking application : $app"
  java -cp "$app:../lib/*" abs.colrows.cli.CliApplication $cmd

  echo "Moving jars to base location"

  find "$targetURL/$product" -mindepth 2 -type f -print -exec mv {} "$targetURL/$product" \;

  echo "deleting additional files"
  find "$targetURL/$product" -type f ! -name '*.jar' -delete
  rm -r "$targetURL/$product"/*/

}
echo "=========================================================================="
echo "=========================== COLROWS CLI TOOL ============================="
echo "=========================================================================="
echo "Choose Option : press numeric key for specific operation"
echo "1. Import .cer/.p12 to keystore"
echo "2. Download Driver Maven dependencies"
echo "Enter your option:"
read option

case "$option" in
"1") importCert ;;
"2") downloadArtifact ;;
esac
